@@ -101,6 +101,8 @@ panel_applet_lock (GtkWidget  *menuitem,
 
 	if (info->move_item)
 		gtk_widget_set_sensitive (info->move_item, !locked);
+	if (info->remove_item)
+		gtk_widget_set_sensitive (info->remove_item, !locked);
 }
 
 static void
@@ -475,7 +477,13 @@ panel_applet_create_menu (AppletInfo  *info,
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (applet_remove_callback), info);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-		gtk_widget_set_sensitive (menuitem, removable);
+		gtk_widget_set_sensitive (menuitem, !locked && removable);
+
+		g_assert (info->remove_item == NULL);
+
+		info->remove_item = menuitem;
+		g_object_add_weak_pointer (G_OBJECT (menuitem),
+					   (gpointer *) &info->remove_item);
 
 		menuitem = gtk_image_menu_item_new ();
 		image = gtk_image_new ();
@@ -1046,13 +1054,15 @@ panel_applet_register (GtkWidget       *applet,
 					  GDK_POINTER_MOTION_HINT_MASK));
 
 	info = g_new0 (AppletInfo, 1);
-	info->type = type;
-	info->widget = applet;
-	info->menu = NULL;
-	info->data = data;
+	info->type         = type;
+	info->widget       = applet;
+	info->menu         = NULL;
+	info->data         = data;
 	info->data_destroy = data_destroy;
-	info->user_menu = NULL;
-	info->move_item = NULL;
+	info->user_menu    = NULL;
+	info->move_item    = NULL;
+	info->remove_item  = NULL;
+	info->id           = g_strdup (id);
 
 	g_object_set_data (G_OBJECT (applet), "applet_info", info);
 
@@ -1119,8 +1129,6 @@ panel_applet_register (GtkWidget       *applet,
 	back_change (info, panel);
 #endif
 
-	if (id) info->id = g_strdup (id);
-
 	if (type != PANEL_OBJECT_BONOBO)
 		gtk_widget_grab_focus (applet);
 	else
