@@ -320,11 +320,15 @@ create_drawer_applet (PanelToplevel    *toplevel,
 	
 	drawer = g_new0 (Drawer, 1);
 
-	if (!use_custom_icon || !custom_icon || !custom_icon [0])
+	if (!use_custom_icon || !custom_icon || !custom_icon [0]) {
 		drawer->button = button_widget_new_from_stock (PANEL_STOCK_DRAWER,
 							       TRUE, orientation);
-	else
+	} else {
 		drawer->button = button_widget_new (custom_icon, TRUE, orientation);
+		/* make sure there is a backup stock id */
+		button_widget_set_stock_id (BUTTON_WIDGET (drawer->button),
+					    PANEL_STOCK_DRAWER);
+	}
 
 	if (!drawer->button) {
 		g_free (drawer);
@@ -443,10 +447,7 @@ panel_drawer_use_custom_icon_changed (GConfClient *client,
 		custom_icon = gconf_client_get_string (client, key, NULL);
 	}
 
-	if (custom_icon && custom_icon [0])
-		button_widget_set_icon_name (BUTTON_WIDGET (drawer->button), custom_icon);
-	else
-		button_widget_set_stock_id (BUTTON_WIDGET (drawer->button), PANEL_STOCK_DRAWER);
+	button_widget_set_icon_name (BUTTON_WIDGET (drawer->button), custom_icon);
 
 	g_free (custom_icon);
 }
@@ -474,10 +475,7 @@ panel_drawer_custom_icon_changed (GConfClient *client,
 		key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, drawer->info->id, "use_custom_icon");
 		use_custom_icon = gconf_client_get_bool (client, key, NULL);
 		
-		if (use_custom_icon)
-			button_widget_set_icon_name (BUTTON_WIDGET (drawer->button), custom_icon);
-		else
-			button_widget_set_stock_id (BUTTON_WIDGET (drawer->button), PANEL_STOCK_DRAWER);
+		button_widget_set_icon_name (BUTTON_WIDGET (drawer->button), custom_icon);
 	}
 }
 
@@ -601,6 +599,57 @@ load_drawer_applet (char          *toplevel_id,
 	panel_drawer_connect_to_gconf (drawer);
 }
 
+static void
+panel_drawer_prepare (const char  *drawer_id,
+		      const char  *custom_icon,
+		      gboolean     use_custom_icon,
+		      const char  *tooltip,
+		      char       **attached_toplevel_id)
+{
+	GConfClient *client;
+	const char  *profile;
+	const char  *key;
+
+	client  = panel_gconf_get_client ();
+	profile = panel_profile_get_name ();
+
+	if (tooltip) {
+		key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, drawer_id, "tooltip");
+		gconf_client_set_string (client, key, tooltip, NULL);
+	}
+
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, drawer_id, "use_custom_icon");
+	gconf_client_set_bool (client, key, use_custom_icon, NULL);
+
+	if (custom_icon) {
+		key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, drawer_id, "custom_icon");
+		gconf_client_set_string (client, key, custom_icon, NULL);
+	}
+
+	if (attached_toplevel_id) {
+		char *toplevel_id;
+		char *toplevel_dir;
+
+		toplevel_id = panel_profile_find_new_id (PANEL_GCONF_TOPLEVELS);
+
+		toplevel_dir = g_strdup_printf (PANEL_CONFIG_DIR "/%s/toplevels/%s",
+						panel_profile_get_name (),
+						toplevel_id);
+		panel_gconf_associate_schemas_in_dir (client, toplevel_dir, PANEL_SCHEMAS_DIR "/toplevels");
+	
+		key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, drawer_id, "attached_toplevel_id");
+		gconf_client_set_string (client, key, toplevel_id, NULL);
+		
+		key = panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, profile, toplevel_id, "enable_buttons");
+		gconf_client_set_bool (client, key, TRUE, NULL);
+
+		key = panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, profile, toplevel_id, "enable_arrows");
+		gconf_client_set_bool (client, key, TRUE, NULL);
+
+		*attached_toplevel_id = toplevel_id;
+	}
+}
+
 void
 panel_drawer_create (PanelToplevel *toplevel,
 		     int            position,
@@ -608,33 +657,36 @@ panel_drawer_create (PanelToplevel *toplevel,
 		     gboolean       use_custom_icon,
 		     const char    *tooltip)
 {
-	GConfClient *client;
-	const char  *profile;
-	const char  *key;
-	char        *id;
-
-	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
+	char *id;
 
 	id = panel_profile_prepare_object (PANEL_OBJECT_DRAWER, toplevel, position, FALSE);
 
-	if (tooltip) {
-		key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "tooltip");
-		gconf_client_set_string (client, key, tooltip, NULL);
-	}
-
-	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "use_custom_icon");
-	gconf_client_set_bool (client, key, use_custom_icon, NULL);
-
-	if (custom_icon) {
-		key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "custom_icon");
-		gconf_client_set_string (client, key, custom_icon, NULL);
-	}
+	panel_drawer_prepare (id, custom_icon, use_custom_icon, tooltip, NULL);
 
 	/* frees id */
 	panel_profile_add_to_list (PANEL_GCONF_OBJECTS, id);
 }
 
+char *
+panel_drawer_create_with_id (const char    *toplevel_id,
+			     int            position,
+			     const char    *custom_icon,
+			     gboolean       use_custom_icon,
+			     const char    *tooltip)
+{
+	char *id;
+	char *attached_toplevel_id = NULL;
+
+	id = panel_profile_prepare_object_with_id (PANEL_OBJECT_DRAWER, toplevel_id, position, FALSE);
+
+	panel_drawer_prepare (id, custom_icon, use_custom_icon, tooltip, &attached_toplevel_id);
+
+	/* frees id */
+	panel_profile_add_to_list (PANEL_GCONF_OBJECTS, g_strdup (id));
+
+	return attached_toplevel_id;
+}
+
 void
 drawer_load_from_gconf (PanelWidget *panel_widget,
 			gboolean     locked,
